#!/usr/bin/env python

from distutils.core import setup

setup(
    name="blocked-table",
    description="Efficient on-disk sorted table format.",
    long_description="""
blocked-table
===================

This package provides an efficient, 2-level indexed table in pure
Python.  The index structure allows for billions of keys to be 
added while retaining low memory usage.

Tables are expected to contain string keys; values are encoded using
the 'json' package and optionally compressed using gzip or snappy
compression.

usage
=====

Building a table::

  import blocked_table
  tb = blocked_table.TableBuilder('/tmp/mytable')
  for i in range(1000000):
    tb.add(str(i), 'Value %d' % i)
  del tb

Reading a table::

  t = blocked_table.open('/tmp/mytable')
  for k, v in t.iteritems(): print k
  v = t.lookup('this is a key')

Utility functions::

  d = dict([('key %d' % i, 'value %d' % i) for i in range(1000000)])
  dictionary_to_table(d, '/tmp/mytable')

""",
    classifiers=['Development Status :: 4 - Beta',
                 'Topic :: Software Development :: Libraries',
                 'License :: OSI Approved :: BSD License',
                 'Intended Audience :: Developers',
                 'Intended Audience :: System Administrators',
                 'Operating System :: POSIX',
                 'Programming Language :: Python :: 2.5',
                 'Programming Language :: Python :: 2.6',
                 'Programming Language :: Python :: 2.7',
                 'Programming Language :: Python :: 3',
                 'Programming Language :: Python :: 3.0',
                 'Programming Language :: Python :: 3.1',
                 'Programming Language :: Python :: 3.2',
                 ],
    author="Russell Power",
    author_email="power@cs.nyu.edu",
    license="BSD",
    version="1.07",
    url="http://rjpower.org/browse.cgi/blocked-table",
    py_modules=['blocked_table'],
)
